@@ -2,7 +2,7 @@ use strict;
 use warnings FATAL => 'all';
 
 package WWW::Mechanize::Cached;
-$WWW::Mechanize::Cached::VERSION = '1.46';
+$WWW::Mechanize::Cached::VERSION = '1.47';
 use 5.006;
 
 use Class::Load 'try_load_class';
@@ -13,7 +13,7 @@ extends 'WWW::Mechanize';
 
 use Carp qw( carp croak );
 use Data::Dump qw( dump );
-use Storable qw( freeze thaw );
+use Storable qw( nfreeze thaw );
 
 has is_cached => ( is => 'rw', isa => Maybe [Bool], default => undef );
 has positive_cache   => ( is => 'rw', isa => Bool, default => 1 );
@@ -97,7 +97,7 @@ around _make_request => sub {
     $response->decode();
     delete $response->{handlers};    ## no critic
 
-    $self->cache->set( $req, freeze($response) ) if $should_cache;
+    $self->cache->set( $req, nfreeze($response) ) if $should_cache;
 
     return $response;
 };
@@ -239,7 +239,7 @@ WWW::Mechanize::Cached - Cache response to be polite
 
 =head1 VERSION
 
-version 1.46
+version 1.47
 
 =head1 SYNOPSIS
 
